@@ -140,9 +140,16 @@ def test_password_non_ascii():
 
 def test_password_without_user():
     url = URL("http://:password@example.com")
+    assert url.user is None
     assert "password" == url.password
 
 
+def test_user_empty_password():
+    url = URL("http://user:@example.com")
+    assert "user" == url.user
+    assert "" == url.password
+
+
 def test_raw_host():
     url = URL("http://example.com")
     assert "example.com" == url.raw_host
@@ -469,6 +476,12 @@ def test_plus_in_path():
     assert "/test/x+y+z/:++/" == url.path
 
 
+def test_nonascii_in_qs():
+    url = URL("http://example.com")
+    url2 = url.with_query({"f\xf8\xf8": "f\xf8\xf8"})
+    assert "http://example.com/?f%C3%B8%C3%B8=f%C3%B8%C3%B8" == str(url2)
+
+
 # modifiers
 
 
@@ -655,6 +668,18 @@ def test_with_fragment_None():
     assert str(url2) == "http://example.com/path"
 
 
+def test_with_fragment_None_matching():
+    url = URL("http://example.com/path")
+    url2 = url.with_fragment(None)
+    assert url is url2
+
+
+def test_with_fragment_matching():
+    url = URL("http://example.com/path#frag")
+    url2 = url.with_fragment("frag")
+    assert url is url2
+
+
 def test_with_fragment_bad_type():
     url = URL("http://example.com")
     with pytest.raises(TypeError):
